<?php

namespace Litecms\Slider\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Litecms\Slider\Forms\Slider as SliderForm;
use Litecms\Slider\Http\Requests\SliderRequest;
use Litecms\Slider\Interfaces\SliderRepositoryInterface;
use Litecms\Slider\Repositories\Eloquent\Filters\SliderResourceFilter;
use Litecms\Slider\Repositories\Eloquent\Presenters\SliderListPresenter;

/**
 * Resource controller class for slider.
 */
class SliderResourceController extends BaseController
{

    /**
     * Initialize slider resource controller.
     *
     *
     * @return null
     */
    public function __construct(SliderRepositoryInterface $slider)
    {
        parent::__construct();
        $this->form = SliderForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('litecms.slider.modules'), 'slider', guard_url('slider'));
        $this->repository = $slider;
    }

    /**
     * Display a list of slider.
     *
     * @return Response
     */
    public function index(SliderRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(SliderResourceFilter::class)
            ->setPresenter(SliderListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('slider::slider.names'))
            ->view('slider::slider.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display slider.
     *
     * @param Request $request
     * @param Model   $slider
     *
     * @return Response
     */
    public function show(SliderRequest $request, SliderRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('slider::slider.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('slider::slider.show')
            ->output();
    }

    /**
     * Show the form for creating a new slider.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(SliderRequest $request, SliderRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('slider::slider.name'))
            ->view('slider::slider.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new slider.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SliderRequest $request, SliderRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('slider::slider.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('slider/slider/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/slider/slider'))
                ->redirect();
        }

    }

    /**
     * Show slider for editing.
     *
     * @param Request $request
     * @param Model   $slider
     *
     * @return Response
     */
    public function edit(SliderRequest $request, SliderRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('slider::slider.name'))
            ->view('slider::slider.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the slider.
     *
     * @param Request $request
     * @param Model   $slider
     *
     * @return Response
     */
    public function update(SliderRequest $request, SliderRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('slider::slider.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('slider/slider/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('slider/slider/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the slider.
     *
     * @param Model   $slider
     *
     * @return Response
     */
    public function destroy(SliderRequest $request, SliderRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('slider::slider.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('slider/slider/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('slider/slider/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
